summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/ui/k_mnu.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker/ui/k_mnu.cpp')
-rw-r--r--kicker/kicker/ui/k_mnu.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index a78971927..6953143c9 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -211,7 +211,7 @@ void PanelKMenu::paletteChanged()
if (!loadSidePixmap())
{
sidePixmap = sideTilePixmap = TQPixmap();
- setMinimumSize( sizeHint() );
+ setMinimumSize( tqsizeHint() );
}
}
@@ -348,7 +348,7 @@ void PanelKMenu::initialize()
if (clients.count() > 0) {
TQIntDictIterator<KickerClientMenu> it(clients);
while (it){
- if (it.current()->text.at(0) != '.')
+ if (it.current()->text.tqat(0) != '.')
insertItem(
it.current()->icon,
it.current()->text,
@@ -419,10 +419,10 @@ void PanelKMenu::repairDisplay(void) {
displayRepairTimer->stop();
// Now do a nasty hack to prevent search bar merging into the side image
- // This forces a layout/repaint of the qpopupmenu
- repaint(); // This ensures that the side bar image was applied
+ // This forces a layout/tqrepaint of the qpopupmenu
+ tqrepaint(); // This ensures that the side bar image was applied
styleChange(tqstyle()); // This forces a call to the private function updateSize(TRUE) inside the qpopupmenu.
- update(); // This repaints the entire popup menu to apply the widget size/alignment changes made above
+ update(); // This repaints the entire popup menu to apply the widget size/tqalignment changes made above
}
}
@@ -584,7 +584,7 @@ void PanelKMenu::showMenu()
TQRect PanelKMenu::sideImageRect()
{
- return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
+ return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
@@ -595,21 +595,21 @@ void PanelKMenu::resizeEvent(TQResizeEvent * e)
PanelServiceMenu::resizeEvent(e);
- setFrameRect( TQStyle::visualRect( TQRect( sidePixmap.width(), 0,
+ setFrameRect( TQStyle::tqvisualRect( TQRect( sidePixmap.width(), 0,
width() - sidePixmap.width(), height() ), this ) );
}
//Workaround Qt3.3.x sizing bug, by ensuring we're always wide enough.
void PanelKMenu::resize(int width, int height)
{
- width = kMax(width, maximumSize().width());
+ width = kMax(width, tqmaximumSize().width());
PanelServiceMenu::resize(width, height);
}
-TQSize PanelKMenu::sizeHint() const
+TQSize PanelKMenu::tqsizeHint() const
{
- TQSize s = PanelServiceMenu::sizeHint();
-// kdDebug(1210) << "PanelKMenu::sizeHint()" << endl;
+ TQSize s = PanelServiceMenu::tqsizeHint();
+// kdDebug(1210) << "PanelKMenu::tqsizeHint()" << endl;
// kdDebug(1210) << s.width() << ", " << s.height() << endl;
return s;
}
@@ -626,7 +626,7 @@ void PanelKMenu::paintEvent(TQPaintEvent * e)
tqstyle().tqdrawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- colorGroup(), TQStyle::Style_Default,
+ tqcolorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();